@@ -91,7 +91,7 @@ class Question(BaseModel):
     ordering = models.PositiveIntegerField(default=0)
 
     def __str__(self):
-        return self.survey.name
+        return f"{self.label}-survey-{self.survey.id}"
 
 
 class UserAnswer(BaseModel):
@@ -124,5 +124,7 @@ class Answer(BaseModel):
             return create_star(active_star=int(self.value))
         elif self.question.type_field == TYPE_FIELD.url:
             return mark_safe(f'<a href="{self.value}" target="_blank">{self.value}</a>')
+        elif self.question.type_field == TYPE_FIELD.radio or self.question.type_field == TYPE_FIELD.select:
+            return self.value.strip().replace('_', ' ').capitalize()
         else:
             return self.value
